Distribution

Enum Distribution 

pub enum Distribution {
    Ubuntu,
    Debian,
    Other(String),
}
Represents a Linux distribution

Variants



Ubuntu

Ubuntu Linux



Debian

Debian Linux



Other(String)

Other distribution

Implementations

Source

impl Distribution

pub fn current() -> Option<Distribution>

Get the current system’s distribution information

Returns None if /etc/os-release is not present or cannot be parsed.

pub fn default_components(&self) -> Vec<&'static str>

Get default components for this distribution

pub fn sources_basename(&self) -> Option<&'static str>

Get the base name for the main sources file for this distribution

For example, returns “ubuntu” for Ubuntu, “debian” for Debian. This can be used to construct filenames like “ubuntu.sources”.

pub fn is_main_repository(&self, repo: &Repository) -> bool

Check if a repository is a main distribution repository