Module error

Module error 

A module for handling errors in apt-sources crate of deb822-rs project. It intends to address error handling in meaningful manner, less vague than just passing String as error.

Enums

LoadError
Errors that can occur when loading repositories from directories
RepositoryError
Errors for APT sources parsing and conversion to/from super::Repository or super::legacy::LegacyRepository