LegacyRepository

Struct LegacyRepository 

pub struct LegacyRepository {
Show 14 fields pub typ: RepositoryType, pub uri: Url, pub suite: String, pub components: Vec<String>, pub architectures: Vec<String>, pub languages: Vec<String>, pub targets: Vec<String>, pub pdiffs: Option<bool>, pub by_hash: Option<YesNoForce>, pub allow_insecure: bool, pub allow_weak: bool, pub allow_downgrade_to_insecure: bool, pub trusted: Option<bool>, pub signature: Option<Signature>, /* private fields */
}
A structure representing APT repository as declared by one-line-style .list file:

type [option=value option=value...] uri suite [component] [component] [...]

According to sources.list(5) man pages, only four fields are mandatory:

  • type either deb or deb-src
  • uri to repository holding valid APT structure
  • suite usually being distribution codename
  • component most of the time main, but it’s a section of the repository; multiple values allowed

The disabled field is just commented out with # followed by whitespaces at the beginning of the valid line

The manpage specifies following optional fields

  • arch comma separated list of binary architectures
  • lang comma separated list of supported natural languages
  • target
  • pdiffs is a yes/no field
  • by-hash is a yes/no/force field
  • allow-insecure is a yes/no field, default no
  • allow-weak is a yes/no field, default no
  • allow-downgrade-to-insecure is a yes/no field, default no
  • trusted us a yes/no field
  • signed-by is a path to the key or fingerprint; optionally followed by exclamation mark
  • check-valid-until is a yes/no field
  • valid-until-min
  • valid-until-max
  • check-date is a yes/no field
  • date-max-future
  • inrelease-path relative path
  • snapshot either enable or a snapshot ID

Note: this module doesn’t support undocumented options.

Fields

typ: RepositoryType

Legacy lists format support one type per line

uri: Url

Single repo address; according to Debian that’s URI, but this type is more advanced than URI from http crate

suite: String

The distribution name as codename or suite type (like stable or testing)

components: Vec<String>

(Optional) Section of the repository, usually main, contrib or non-free return None if repository is Flat Repository Format (https://wiki.debian.org/DebianRepository/Format#Flat_Repository_Format)

architectures: Vec<String>

(Optional) Architectures binaries from this repository run on

languages: Vec<String>

(Optional) Translations support to download

targets: Vec<String>

(Optional) Download targets to acquire from this source

pdiffs: Option<bool>

(Optional) Controls if APT should try PDiffs instead of downloading indexes entirely; if not set defaults to configuration option Acquire::PDiffs

by_hash: Option<YesNoForce>

(Optional) Controls if APT should try to acquire indexes via a URI constructed from a hashsum of the expected file

allow_insecure: bool

(Optional) If yes circumvents parts of apt-secure, don’t thread lightly

allow_weak: bool

(Optional) If yes circumvents parts of apt-secure, don’t thread lightly

allow_downgrade_to_insecure: bool

(Optional) If yes circumvents parts of apt-secure, don’t thread lightly

trusted: Option<bool>

(Optional) If set forces whether APT considers source as trusted or no (default not present is a third state)

signature: Option<Signature>

(Optional) Contains either absolute path to GPG keyring or embedded GPG public key block, if not set APT uses all trusted keys; I can’t find example of using with fingerprints